@@ -8,7 +8,7 @@ This package provides functions for:
     - Exporting ranked results to JSON/CSV
 
 Main API:
-    - crawl_and_rank
+    - crawl_and_rank_frontier
     - rank
     - rank_and_save_publications_JSON
     - rank_and_save_publications_CSV
@@ -23,10 +23,18 @@ Submodules:
     - doi_utils
 """
 
+from .citation_crawler import crawl_citation_neighborhood
 from .paperank_core import (
-    crawl_and_rank,
+    crawl_and_rank_frontier,
     rank,
-    rank_and_save_publications_JSON,
     rank_and_save_publications_CSV,
+    rank_and_save_publications_JSON,
 )
-from .citation_crawler import get_citation_neighborhood
\ No newline at end of file
+
+__all__ = [
+    "crawl_citation_neighborhood",
+    "crawl_and_rank_frontier",
+    "rank",
+    "rank_and_save_publications_CSV",
+    "rank_and_save_publications_JSON",
+]
