@@ -1,7 +1,8 @@
 import re
 from urllib.parse import quote, unquote
 
-_DOI_PREFIX_RE = re.compile(r'^https?://(dx\.)?doi\.org/', re.IGNORECASE)
+_DOI_PREFIX_RE = re.compile(r"^https?://(dx\.)?doi\.org/", re.IGNORECASE)
+
 
 def normalize_doi(doi: str) -> str:
     """
@@ -24,9 +25,10 @@ def normalize_doi(doi: str) -> str:
     if not doi:
         return doi
     d: str = unquote(doi.strip())
-    d = _DOI_PREFIX_RE.sub('', d)
+    d = _DOI_PREFIX_RE.sub("", d)
     return d.lower()
 
+
 def doi_to_path_segment(doi: str) -> str:
     """
     Convert a DOI string to a URL-safe path segment suitable for use in REST API endpoints.
@@ -41,4 +43,4 @@ def doi_to_path_segment(doi: str) -> str:
         >>> doi_to_path_segment("10.1016/j.ejor.2016.12.001")
         '10.1016%2Fj.ejor.2016.12.001'
     """
-    return quote(normalize_doi(doi), safe='')
\ No newline at end of file
+    return quote(normalize_doi(doi), safe="")
